==> nted_0.24.1.orig.tar.gz: nted-0.24.1/commands/appendsystemcommand.h <==
/****************************************************************************************/
/*											*/
/* This program is free software; you can redistribute it and/or modify it under the	*/
/* terms of the GNU General Public License as published by the Free Software		*/
/* Foundation; either version 2 of the License, or (at your option) any later version.	*/
/*											*/
/* This program is distributed in the hope that it will be useful, but WITHOUT ANY	*/
/* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A	*/
/* PARTICULAR PURPOSE. See the GNU General Public License for more details.		*/
/*											*/
/* You should have received a copy of the GNU General Public License along with this	*/
/* program; (See "COPYING"). If not, If not, see <http://www.gnu.org/licenses/>.        */
/*											*/
/*--------------------------------------------------------------------------------------*/
/*											*/
/*  Copyright   Joerg Anders, TU Chemnitz, Fakultaet fuer Informatik, GERMANY           */
/*		ja@informatik.tu-chemnitz.de						*/
/*											*/
/*											*/
/****************************************************************************************/

#ifndef APPEND_SYSTEM_COMMAND_H

#define APPEND_SYSTEM_COMMAND_H
#include "config.h"
#include "command.h"
#include <gtk/gtk.h>

class NedSystem;
class NedPage;

class NedAppendSystemCommand : public NedCommand {
	public:	
		NedAppendSystemCommand(NedPage *page, double width, GList **systems_ptr, unsigned int start_measure_number);
		~NedAppendSystemCommand();
		virtual void execute(bool adjust = false);
		virtual void unexecute(bool adjust = false);
	private:
		GList **m_systems_ptr;
		NedPage *m_page;
		NedSystem *m_system;
};

#endif /* APPEND_SYSTEM_COMMAND_H */

==> nted_1.10.7.orig.tar.gz: nted-1.10.7/commands/appendsystemcommand.h <==
/****************************************************************************************/
/*											*/
/* This program is free software; you can redistribute it and/or modify it under the	*/
/* terms of the GNU General Public License as published by the Free Software		*/
/* Foundation; either version 2 of the License, or (at your option) any later version.	*/
/*											*/
/* This program is distributed in the hope that it will be useful, but WITHOUT ANY	*/
/* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A	*/
/* PARTICULAR PURPOSE. See the GNU General Public License for more details.		*/
/*											*/
/* You should have received a copy of the GNU General Public License along with this	*/
/* program; (See "COPYING"). If not, If not, see <http://www.gnu.org/licenses/>.        */
/*											*/
/*--------------------------------------------------------------------------------------*/
/*											*/
/*  Copyright   Joerg Anders, TU Chemnitz, Fakultaet fuer Informatik, GERMANY           */
/*		ja@informatik.tu-chemnitz.de						*/
/*											*/
/*											*/
/****************************************************************************************/

#ifndef APPEND_SYSTEM_COMMAND_H

#define APPEND_SYSTEM_COMMAND_H
#include "config.h"
#include "command.h"
#include <gtk/gtk.h>

class NedSystem;
class NedPage;

class NedAppendSystemCommand : public NedCommand {
	public:	
		NedAppendSystemCommand(NedPage *page);
		~NedAppendSystemCommand();
		NedSystem *getSystem() {return m_system;}
		virtual void execute(bool adjust = false);
		virtual void unexecute(bool adjust = false);
	private:
		NedPage *m_page;
		NedSystem *m_system;
};

#endif /* APPEND_SYSTEM_COMMAND_H */
